@@ -4,14 +4,10 @@ set -e
 
 PYTHON=${1:-python}
 
-for x in examples/hlapi/v3arch/asyncore/sync/manager/cmdgen/*.py \
-         examples/hlapi/v3arch/asyncore/sync/agent/ntforg/*.py \
-         examples/hlapi/v3arch/asyncore/manager/cmdgen/*.py \
-         examples/hlapi/v3arch/asyncore/agent/ntforg/*.py \
-         examples/hlapi/v1arch/asyncore/sync/manager/cmdgen/*.py \
-         examples/hlapi/v1arch/asyncore/sync/agent/ntforg/*.py \
-         examples/hlapi/v1arch/asyncore/manager/cmdgen/*.py \
-         examples/hlapi/v1arch/asyncore/agent/ntforg/*.py \
+for x in examples/hlapi/asyncore/sync/manager/cmdgen/*.py \
+         examples/hlapi/asyncore/sync/agent/ntforg/*.py \
+         examples/hlapi/asyncore/manager/cmdgen/*.py \
+         examples/hlapi/asyncore/agent/ntforg/*.py \
          examples/v3arch/asyncore/manager/cmdgen/*.py \
          examples/v3arch/asyncore/agent/ntforg/*.py \
          examples/v1arch/asyncore/manager/cmdgen/*.py \
